/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.type;

import nl.cloudfarming.client.isobus.model.BinaryDataType;
import nl.cloudfarming.client.isobus.model.XmlField;

/**
 * Describes the dataTypes of the ISO 17783-10 PTN element in the binary file  
 * @author Gerben Feenstra
 */
public enum PositionFieldEnum implements XmlField {

    /** PTN A **/
    POSITION_NORTH("A", BinaryDataType.BIT32_SIGNED),
    /** PTN B **/
    POSITION_EAST("B", BinaryDataType.BIT32_SIGNED),
    /** PTN C **/
    POSITION_UP("C", BinaryDataType.BIT32_SIGNED),
    /** PTN D **/
    POSITION_STATUS("D", BinaryDataType.BIT8_SIGNED),
    /** PTN E **/
    POSITION_PDOP("E", BinaryDataType.BIT16_UNSIGNED),
    /** PTN F **/
    POSITION_HDOP("F", BinaryDataType.BIT16_UNSIGNED),
    /** PTN G **/
    POSITION_SAT_NR("G", BinaryDataType.BIT8_SIGNED),
    /** PTN H **/
    POSITION_GPS_UTC_TIME("H", BinaryDataType.BIT32_UNSIGNED),
    /** PTN I **/
    POSITION_GPS_UTC_DATE("I", BinaryDataType.BIT16_UNSIGNED);
    
    String xmlField = "";
    BinaryDataType dataType = null;

    PositionFieldEnum(String xmlField, BinaryDataType dataType) {
        this.xmlField = xmlField;
        this.dataType = dataType;
    }

    @Override
    public String getAttributeName() {
        return xmlField;
    }

    @Override
    public BinaryDataType getDataType() {
        return dataType;
    }
}
