/*
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Contributors:
 *    johan - initial API and implementation and/or initial documentation
 */
package nl.cloudfarming.client.isobus.type;

import java.awt.BorderLayout;
import java.awt.Color;
import javax.swing.Action;
import javax.swing.JComponent;
import javax.swing.JLabel;
import javax.swing.JPanel;
import javax.swing.JToolBar;
import nl.cloudfarming.client.geoviewer.Grid;
import nl.cloudfarming.client.geoviewer.render.GridCoverage2DPreviewPanel;
import nl.cloudfarming.client.isobus.model.DDI;
import nl.cloudfarming.client.isobus.model.util.TimeLogUtil;
import nl.cloudfarming.client.util.swing.MessagePanel;
import org.geotools.coverage.grid.GridCoverage2D;
import org.netbeans.core.spi.multiview.CloseOperationState;
import org.netbeans.core.spi.multiview.MultiViewElement;
import org.netbeans.core.spi.multiview.MultiViewElementCallback;
import org.openide.awt.UndoRedo;
import org.openide.util.Lookup;
import org.openide.util.NbBundle;
import org.openide.windows.TopComponent;

/**
 *
 * @author johan
 */
@MultiViewElement.Registration(
    displayName = "#LBL_TimeLogBinary_VISUAL",
iconBase = TimeLogBinaryDataObject.ICON_BASE,
mimeType = TimeLogBinaryDataObject.MIME_TYPE,
persistenceType = TopComponent.PERSISTENCE_NEVER,
preferredID = "TimeLogBinaryVisual",
position = 2000)
@NbBundle.Messages({
    "LBL_TimeLogBinary_VISUAL=Visual",
    "TimeLogBinaryVisualElement warn no ddi=No rate/yield data available",
    "TimeLogBinaryVisualElement warn no raster=No raster data available (see log file for details)",
})
public class TimeLogBinaryVisualElement extends JPanel implements MultiViewElement {
    
    private TimeLogBinaryDataObject obj;
    private JToolBar toolbar = new JToolBar();
    private transient MultiViewElementCallback callback;

    private final MessagePanel messagePanel = new MessagePanel(MessagePanel.LARGE_ICON);

    /**
     * Creates new form TimeLogBinaryVisualElement
     */
    public TimeLogBinaryVisualElement(Lookup lkp) {
        obj = lkp.lookup(TimeLogBinaryDataObject.class);
        assert obj != null;
        
        //initComponents();
        init(lkp);
    }
    
    private void init(Lookup lkp) {
        setLayout(new BorderLayout());
        setBackground(Color.white);
        
        add(messagePanel, BorderLayout.NORTH);
        
        //TODO: preconditions
        // - enough valid PTN values to create a boundingbox
        // - a plottable ddi in the xml header
        // and then move these checks to somewhere earlier in the process, since they
        // also apply when showing something on the map (e.g. don't add grid to lookup)
        TimeLogXMLDataObject header = obj.getXmlHeader();
        DDI ddi = TimeLogUtil.getAppliedRateYieldDDI(header.getDDIs());
        if (ddi == null) {
            messagePanel.setWarning(Bundle.TimeLogBinaryVisualElement_warn_no_ddi());
            return;
        }

        Grid grid = obj.getRateYieldGrid();
        GridCoverage2D coverage = grid.getRenderObject(null);
        if (coverage == null) {
            // RasterFactory returned null, log will have more details:
            messagePanel.setWarning(Bundle.TimeLogBinaryVisualElement_warn_no_raster());
            return;
        }
        
        add(new GridCoverage2DPreviewPanel(coverage, obj.getRateYieldPalette()));
        add(new JLabel(ddi.toString()), BorderLayout.NORTH);
    }

    @Override
    public String getName() {
        return "TimeLogBinaryVisualElement";
    }

    /**
     * This method is called from within the constructor to initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is always
     * regenerated by the Form Editor.
     */
    @SuppressWarnings("unchecked")
    // <editor-fold defaultstate="collapsed" desc="Generated Code">//GEN-BEGIN:initComponents
    private void initComponents() {

        javax.swing.GroupLayout layout = new javax.swing.GroupLayout(this);
        this.setLayout(layout);
        layout.setHorizontalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 400, Short.MAX_VALUE)
        );
        layout.setVerticalGroup(
            layout.createParallelGroup(javax.swing.GroupLayout.Alignment.LEADING)
            .addGap(0, 300, Short.MAX_VALUE)
        );
    }// </editor-fold>//GEN-END:initComponents
    // Variables declaration - do not modify//GEN-BEGIN:variables
    // End of variables declaration//GEN-END:variables

    @Override
    public JComponent getVisualRepresentation() {
        return this;
    }

    @Override
    public JComponent getToolbarRepresentation() {
        return toolbar;
    }

    @Override
    public Action[] getActions() {
        return new Action[0];
    }

    @Override
    public Lookup getLookup() {
        return obj.getLookup();
    }

    @Override
    public void componentOpened() {
    }

    @Override
    public void componentClosed() {
    }

    @Override
    public void componentShowing() {
        if (callback != null) {
            updateName();
        }
    }

    public void updateName() {
        if (callback != null) {
            String name = obj.getName();
            TopComponent tc = callback.getTopComponent();
            tc.setHtmlDisplayName(name);
            tc.setDisplayName(name);
            tc.setName(getName());
            tc.setToolTipText(getToolTipText());
        }
    }

    @Override
    public void componentHidden() {
    }

    @Override
    public void componentActivated() {
    }

    @Override
    public void componentDeactivated() {
    }

    @Override
    public UndoRedo getUndoRedo() {
        return UndoRedo.NONE;
    }

    @Override
    public void setMultiViewCallback(MultiViewElementCallback callback) {
        this.callback = callback;
    }

    @Override
    public CloseOperationState canCloseElement() {
        return CloseOperationState.STATE_OK;
    }

}
