/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.type.visual;

import java.awt.Dialog;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import javax.swing.event.ListSelectionEvent;
import javax.swing.event.ListSelectionListener;
import nl.cloudfarming.client.isobus.model.IsobusManager;
import nl.cloudfarming.client.util.swing.ASBodyPanel;
import org.netbeans.api.project.Project;
import org.openide.DialogDescriptor;
import org.openide.DialogDisplayer;
import org.openide.filesystems.FileObject;
import org.openide.util.Lookup;

/**
 * Controller for the TaskdataSelectionPanel Will control validation And will
 * perform the writer call to write the task to the existing TASKDATA file
 *
 * @author Merijn Zengers
 */
public class TaskdataSelectionController {

    private Project project;
    private ASBodyPanel panel;
    private TaskdataSelectionPanel taskdataSelectionPanel;

    public TaskdataSelectionController(Project project) {
        this.project = project;
    }

    /**
     * Get the main component from this controller This is a ASBodypanel
     * containing the TaskdataSelectionPanel
     *
     * @return ASBodyPanel
     */
    private ASBodyPanel getComponent() {
        if (panel == null) {
            panel = new ASBodyPanel(getPanel());
            panel.setTitle(Bundle.TaskdataSelectionPanel_title());
        }
        return panel;
    }

    /**
     * get the TaskdataSelectionPanel
     *
     * @return
     */
    private TaskdataSelectionPanel getPanel() {
        if (taskdataSelectionPanel == null) {
            taskdataSelectionPanel = new TaskdataSelectionPanel();
        }
        return taskdataSelectionPanel;
    }

    /**
     * Opens the dialog
     */
    public void open() {
        DialogDescriptor descriptor = new DialogDescriptor(getComponent(), Bundle.TaskdataSelectionPanel_title(), true, new Object[]{getPanel().getAddButton(), getPanel().getCancelButton()}, getPanel().getCancelButton(), DialogDescriptor.DEFAULT_ALIGN, null, null);

        TaskDataSelectionListener selectionListener = new TaskDataSelectionListener();
        getPanel().addTaskdataFileSelectionListener(selectionListener);
        getPanel().getAddButton().addActionListener(new AddButtonListener());
        IsobusManager manager = Lookup.getDefault().lookup(IsobusManager.class);
        assert manager != null : "isobusmanger should be found";
        FileObject[] isobusFolders = manager.getTaskDataFolders(project);
        String[] isobusNames = new String[isobusFolders.length];
        int counter = 0;
        for(FileObject isobusFolder : isobusFolders){
            isobusNames[counter] = isobusFolder.getName();
            counter++;
        }
        
        getPanel().setTaskdataFiles(isobusNames);
        Dialog dialog = DialogDisplayer.getDefault().createDialog(descriptor);
        dialog.setVisible(true);
        dialog.toFront();

        getPanel().removeTaskdataFileSelectionListener(selectionListener);
    }

    /**
     * Based on boolean will set the create button enabled or disabled
     *
     * @param valid
     */
    private void setValid(boolean valid) {
        getPanel().getAddButton().setEnabled(valid);
    }

    /**
     * Checks if the selected taskdata file is valid based on that calls the setValid method 
     */
    private class TaskDataSelectionListener implements ListSelectionListener {

        @Override
        public void valueChanged(ListSelectionEvent lse) {
            setValid(getPanel().getSelectedTaskdataFile() != null && !getPanel().getSelectedTaskdataFile().equals(""));
        }
    }
    
    /**
     * Listens to actions on the add button
     * Will call the writer to write the task to the selected taskdata file 
     */
    private class AddButtonListener implements ActionListener{

        @Override
        public void actionPerformed(ActionEvent ae) {
            throw new UnsupportedOperationException("Not supported yet.");
        }
        
    }
}
