/**
 * Copyright (C) 2008-2012 AgroSense Foundation.
 *
 * AgroSense is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * There are special exceptions to the terms and conditions of the GPLv3 as it is applied to
 * this software, see the FLOSS License Exception
 * <http://www.agrosense.eu/foss-exception.html>.
 *
 * AgroSense is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with AgroSense.  If not, see <http://www.gnu.org/licenses/>.
 */
package nl.cloudfarming.client.isobus.type.visual;

import java.awt.Dimension;
import javax.swing.*;
import javax.swing.event.ListSelectionListener;
import net.miginfocom.swing.MigLayout;
import org.openide.util.NbBundle;

/**
 * Panel in which the user can select a TASKDATA file.
 * You can add a listener to the contained list to listen to list selection changes
 *
 * @author Merijn Zengers
 */
@NbBundle.Messages({"TaskdataSelectionPanel cancel button text=Cancel",
                    "TaskdataSelectionPanel add button text=Add",
                    "TaskdataSelectionPanel title=Select a taskdata file",
                    "TaskdataSelectionPanel select taskdata label text=Select a taskdata file"})
public class TaskdataSelectionPanel extends JPanel {

    private JButton cancelButton;
    private JButton addButton;
    private JList<String> taskDataFiles;
    private static final int MAX_HEIGHT = 300;
    private static final int MAX_WIDTH = 600;
    private static final int TASKDATA_FILES_LIST_WIDTH = 200;

    public TaskdataSelectionPanel(){
        this.setLayout(new MigLayout("wrap1"));
        this.setMaximumSize(new Dimension(MAX_WIDTH, MAX_HEIGHT));
        JLabel selectTaskdataLabel = new JLabel(Bundle.TaskdataSelectionPanel_select_taskdata_label_text());
        taskDataFiles = new JList<>();
        taskDataFiles.setSelectionMode(ListSelectionModel.SINGLE_SELECTION);
        JScrollPane pane = new JScrollPane(taskDataFiles);
        pane.setHorizontalScrollBarPolicy(JScrollPane.HORIZONTAL_SCROLLBAR_NEVER);
        pane.setVerticalScrollBarPolicy(JScrollPane.VERTICAL_SCROLLBAR_AS_NEEDED);
        pane.setMinimumSize(new Dimension(TASKDATA_FILES_LIST_WIDTH, 0));
        this.add(selectTaskdataLabel);
        this.add(pane);
        
        getAddButton().setEnabled(false);
    }
    
    /**
     * Set the taskdata files from which the user can make its selection
     *
     * @param files
     */
    public void setTaskdataFiles(String[] files) {
        taskDataFiles.removeAll();
        taskDataFiles.setListData(files);
    }
    
    /**
     * Get the selected value from the TaskdataFiles
     * @return 
     */
    public String getSelectedTaskdataFile(){
        return taskDataFiles.getSelectedValue();
    }
    
    /**
     * Add a ListSelectionListener to the TaskDataFiles list
     * @param listener 
     */
    public void addTaskdataFileSelectionListener(ListSelectionListener listener){
        taskDataFiles.addListSelectionListener(listener);
    }
    
    /**
     * Remove a ListSelectionListener from the TaskdataFiles list
     * @param listener 
     */
    public void removeTaskdataFileSelectionListener(ListSelectionListener listener){
        taskDataFiles.removeListSelectionListener(listener);
    }

    /**
     * Get the cancel button for the dialog
     *
     * @return
     */
    public JButton getCancelButton() {
        if (cancelButton == null) {
            cancelButton = new JButton(Bundle.TaskdataSelectionPanel_cancel_button_text());
        }
        return cancelButton;
    }

    /**
     * Get the Create button for the dialog
     *
     * @return
     */
    public final JButton getAddButton() {
        if (addButton == null) {
            addButton = new JButton(Bundle.TaskdataSelectionPanel_add_button_text());
        }
        return addButton;
    }
}
